#
# spec file for package MozillaFirefox-branding-openSUSE
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2008-2024 Wolfgang Rosenauer
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkgname firefox-esr-branding-openSUSE

%if "%{pkgname}" == "MozillaFirefox-branding-openSUSE"
%define targetpkg MozillaFirefox
%define progdir %{_libdir}/firefox
%define appname Firefox
%else
%if "%{pkgname}" == "firefox-esr-branding-openSUSE"
%define targetpkg firefox-esr
%define progdir %{_libdir}/firefox-esr
%define appname Firefox ESR
%else
%define pkgname MozillaFirefox-branding-openSUSE
ExclusiveArch:  do-not-build
%endif
%endif

Name:           %{pkgname}
BuildRequires:  bc
BuildRequires:  unzip
BuildRequires:  zip
Version:        68
Release:        5.3
Summary:        openSUSE branding of MozillaFirefox
License:        BSD-3-Clause AND GPL-2.0-or-later
Group:          Productivity/Networking/Web/Browsers
URL:            http://www.opensuse.org
Source:         susefox-20120626.tar.bz2
Source1:        opensuse-software.xml.in
Source2:        all-openSUSE.js
Source3:        firefox-suse-default-prefs.js
Source4:        firefox.schemas
Source5:        distribution.ini.in
Source6:        MozillaFirefox-branding-openSUSE-COPYING
Supplements:    packageand(%{targetpkg}:branding-openSUSE)
Provides:       %{targetpkg}-branding = %{version}
Conflicts:      otherproviders(%{targetpkg}-branding)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%global libgssapi  libgssapi_krb5.so.2

%global suseversion undefined
%if %suse_version == 1315
  # Leap 42
  %if %sle_version == 120100
    %global suseversion 42.1
  %else
    %if %sle_version == 120200
      %global suseversion 42.2
    %else
      %if %sle_version == 120300
        %global suseversion 42.3
      %endif
    %endif
  %endif
%endif
%if %suse_version == 1500
  # Leap 15
  %if %sle_version == 150000
    %global suseversion 15.0
  %else
    %if %sle_version == 150100
      %global suseversion 15.1
    %else
      %if %sle_version == 150200
        %global suseversion 15.2
      %else
        %if %sle_version == 150300
          %global suseversion 15.3
        %else
          %if %sle_version == 150400
            %global suseversion 15.4
          %else
            %if %sle_version == 150500
              %global suseversion 15.5
            %endif
          %endif
        %endif
      %endif
    %endif
  %endif
%endif

%if %suse_version >= 1550
  # Tumbleweed
  %global suseversion Tumbleweed
%endif

# Leap or not
%if 0%{?sle_version}
  %global prjname Leap:%{suseversion}
  %global distname openSUSE Leap
%else
  %global prjname %{suseversion}
  %global distname openSUSE
%endif

%global homepage      https://search.opensuse.org/
%global susefox       0
%global susefox_guid  {ec8030f7-c20a-464f-9b0e-13a3a9e97384}

%description
This package provides openSUSE look and feel for Firefox.

%prep
cp -a %{SOURCE6} COPYING
%if %susefox
%setup -n susefox -q
mv COPYING COPYING.susefox
%endif

%build
%if %susefox
./build.sh
%endif

%install
# apply SUSE defaults
sed -e 's,GSSAPI,%{libgssapi},g' \
    %{SOURCE3} > firefox-openSUSE.js

install -d %{buildroot}%{progdir}/browser/defaults/preferences/
install -m 0644 firefox-openSUSE.js %{buildroot}%{progdir}/browser/defaults/preferences/

install -d %{buildroot}%{progdir}/defaults/pref/
install -m 0644 %{SOURCE2} %{buildroot}%{progdir}/defaults/pref/

# distribution.ini -- openSUSE bookmarks, homepage and Mozilla partner info
sed -e 's,%%VERSION%%,%{suseversion},g
s,%%HOMEPAGE%%,%{homepage},g
s,%%FLAVOR%%,%{appname},g
s,%%DIST%%,%{distname},g' \
    %{SOURCE5} > distribution.ini

install -d %{buildroot}%{progdir}/distribution/
install -m 0644 distribution.ini %{buildroot}%{progdir}/distribution/

# openSUSE software search plugin
sed -e 's,%%PRJNAME%%,%{prjname},g' \
    %{SOURCE1} > opensuse-software.xml

install -d %{buildroot}%{progdir}/distribution/searchplugins/common/
install -m 0644 opensuse-software.xml %{buildroot}%{progdir}/distribution/searchplugins/common/

%if %susefox
# install the system extension
unzip -u susefox\@opensuse.org ../susefox.xpi
mkdir -p %{buildroot}%{_datadir}/mozilla/extensions/%{susefox_guid}/
cp -r susefox\@opensuse.org \
    %{buildroot}%{_datadir}/mozilla/extensions/%{susefox_guid}/
%endif

%files
%defattr(-,root,root)
%if %susefox
%license COPYING.susefox
%license ../COPYING
%{_datadir}/mozilla
%endif
%{progdir}

%changelog
* Sun Nov 10 2024 Wolfgang Rosenauer <wr@rosenauer.org>
- do not use XDG for mime-handler as it does not handle the default
  browser check correctly
* Mon Nov  4 2024 Wolfgang Rosenauer <wr@rosenauer.org>
- add properties to use xdg-desktop-portal (boo#1226112)
* Tue Aug  9 2022 Yuchen Lin <mlin+factory@suse.de>
- add sle_version 150500 check
* Sat Feb 26 2022 Rischio Cinico <rischiocinico@gmail.com>
- add some useful links about openSUSE in the about:newtab page
* Fri Dec 17 2021 Yuchen Lin <mlin+factory@suse.de>
- add sle_version 150300 and 150400 check
* Fri Sep 24 2021 Andreas Stieger <andreas.stieger@gmx.de>
- use HTTPS for software search plugin
* Thu Mar 19 2020 Stasiek Michalski <stasiek@michalski.cc>
- Update the default homepage and the bookmark icons
* Fri Oct  4 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- removed extensions preferences (moved to core package)
- use multibuild to provide branding package for
  MozillaFirefox and firefox-esr
* Mon Sep  9 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- layout.word_select.stop_at_punctuation -> true (boo#1133163)
* Wed Jul 17 2019 Lubos Kocman <Lubos.Kocman+factory@suse.de>
- recognize Leap 15.2 via sle_version
* Sun May  5 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- recognize Leap 15 via sle_version (required for >= 15.1)
* Tue Apr 23 2019 Wolfgang Rosenauer <wr@rosenauer.org>
- bump version to 60 for SLE compatibility (bsc#1128316)
* Sat Aug 25 2018 wr@rosenauer.org
- removed intl.locale.matchOS
  * it's not used in recent versions and it was set in the general
    openSUSE Firefox package since 2011
* Sun Apr  1 2018 wr@rosenauer.org
- recognize Leap 15.0 (boo#1087713)
* Mon Jun  5 2017 wr@rosenauer.org
- really fix boo#1036679 (recognize Leap 42.3)
* Fri Apr 28 2017 wr@rosenauer.org
- recognize Leap 42.3 (boo#1036679)
* Fri Dec  9 2016 qantas94heavy@gmail.com
- Fix openSUSE bookmarks not added to default profile (boo#1014292)
  * Move openSUSE bookmarks from toolbar to menu
  * Use local favicon for all bookmarks (Firefox 45+)
  * Fix links to "openSUSE Documentation" and "How to Participate"
    (boo#704121, boo#953164)
- Remove DuckDuckGo search plugin (included upstream)
- Clean up spec file
  * Change $RPM_BUILD_ROOT to %%{buildroot}
  * Remove %%clean section
  * Escape %% symbols
* Mon Jul 11 2016 dimstar@opensuse.org
- Identify the different Leap versions correctly (up to Leap 42.2)
  (boo#987969).
* Fri Dec 18 2015 wr@rosenauer.org
- identify Tumbleweed correctly
* Mon Oct 19 2015 wr@rosenauer.org
- change homepage to https://www.opensuse.org/searchPage/
  (boo#950948, boo#950949)
* Sun Jul 26 2015 wr@rosenauer.org
- identify Leap 42.1 correctly
- searchplugins need to be placed under distribution with FF 40
- disable susefox
  * its main purpose the plugin finder service misses server
    side maintenance and NPAPI plugins are being obsoleted sooner
    or later
- homepage setting moved back from susefox to distribution
  configuration
* Mon Mar 25 2013 wr@rosenauer.org
- modified file locations for Firefox 21 and above
* Thu Jan 31 2013 wr@rosenauer.org
- added DuckDuckGo as search option (bnc#801121)
* Tue Aug  7 2012 wr@rosenauer.org
- move Firefox specific prefs to defaults/preferences (bnc#774914)
* Tue Jun 26 2012 wr@rosenauer.org
- update susefox to snapshot 20120626
  * add window controls for Gnome 3 (bnc#768942)
* Thu Mar 15 2012 wr@rosenauer.org
- bumped version to 6.0
- support firefox-esr RPM packages
- removed MozillaFirefox build dependency and PreReq
  * everything controlled by Supplements and Requirements from
    base package
* Wed Dec 21 2011 wr@rosenauer.org
- make openSUSE software search version specific (bnc#737709)
* Fri Nov 18 2011 wr@rosenauer.org
- disable addon check completely as scopes are not working
  correctly with Firefox 8
* Fri Nov 11 2011 wr@rosenauer.org
- do not disable global addons on update check
* Tue Nov  8 2011 wr@rosenauer.org
- update susefox to snapshot 20111108 (1.0.2)
  * removed statusbar stuff (fix bnc#707628)
* Thu Oct 20 2011 wr@rosenauer.org
- make susefox compatible up to Firefox 9
- browser.startup.homepage is now a property in susefox as the
  resource:// URI is useless in omnijar setup (bnc#721421)
- no welcome and override startpages
* Wed Sep 14 2011 wr@rosenauer.org
- update susefox
  * marked compatible up to FF7
* Mon Jun 27 2011 ro@suse.de
- add directory to filelist to fix build
* Sat May 21 2011 wr@rosenauer.org
- update susefox
  * marked compatible with FF5
* Fri Apr 15 2011 wr@rosenauer.org
- update to version 5.0
  * supports openSUSE Firefox 5 and higher
    (compatibility with standalone Firefox)
- added all-openSUSE.js (previously in xulrunner)
* Tue Oct 26 2010 wr@rosenauer.org
- update susefox to snapshot 20101026
  * Updated link to openSUSE wiki page
  * Mistake in cs-CZ locale (bnc#637368)
* Mon Aug 30 2010 wr@rosenauer.org
- fixed build for Factory by getting the needed RPM macros
- override browser.startup.homepage reference
* Thu Aug 12 2010 wr@rosenauer.org
- bumped package version to 4.0
- update susefox to snapshot 20100812
  * compatibility with Firefox 4
* Wed Jun  9 2010 wr@rosenauer.org
- update susefox to snapshot 20100609
  * added HU translation
* Fri May 28 2010 javier@opensuse.org
- switch Planet openSUSE's feed to planet.opensuse.org
* Sun Dec  6 2009 wr@rosenauer.org
- update susefox to snapshot 20091206 (1.0.1)
  * compatible with Firefox 3.6
* Wed Nov  4 2009 wr@rosenauer.org
- removed obsolete prefs
* Fri Oct 23 2009 wr@rosenauer.org
- update susefox to snapshot 20091023
  * remove unneeded error dialog (bnc#549496)
* Mon Sep 28 2009 wr@rosenauer.org
- update susefox to snapshot 20090928
  * fixed syntax error in install.rdf which prevented the addon from
    being loaded
* Fri Sep 25 2009 wr@rosenauer.org
- update susefox to snapshot 20090925
  * added pt-BR locale
  * use pluginfinder.opensuse-community.org as official backend
* Sun Sep 13 2009 wr@rosenauer.org
- update susefox to snapshot 20090914
  * offer the homepage link also in en-US locale
* Fri Jul 10 2009 wr@rosenauer.org
- update susefox to snapshot 20090710
  * added link to the new "homepage" of the addon
  * manage content plugins menuitem is always enabled now
  * plugin installer wizard skips the results list correctly
  * fixed a few issues
* Sat Jul  4 2009 wr@rosenauer.org
- update susefox to snapshot 20090703
  * Remove superfluous select field
  * Remove the bug reporting hint for missing upstream descriptions
  * added nl locale from Freek de Kruijf
  * Add it locale as provided by Andrea Turrini
* Tue Jun 30 2009 wr@rosenauer.org
- add distribution.ini (mainly for having a distribution version
  in Firefox prefs e.g. needed for the susefox addon)
- added susefox extension
  * supports custom plugin finder service
  * integrates PFS with YaST
  * allows setting of the default mimetype handler plugin if there
    are more than one installed
* Tue May 19 2009 wr@rosenauer.org
- set accessibility.typeaheadfind.soundURL to "default" (bnc#505289)
  (that uses a wav packaged in toolkit and FF might not be able
  to play it if esd is not functional)
* Mon May  4 2009 wr@rosenauer.org
- bumped version to 3.5 to reflect FF version bump
- updated firefox.schemas
- removed spec support for distributions before 10.3
- removed obsolete prefs
* Mon Dec  8 2008 hfiguiere@suse.de
- Fix a type in firefox-suse-default-prefs.js
* Fri Nov 21 2008 maw@suse.de
- Review and approve changes.
* Fri Nov 14 2008 wr@rosenauer.org
- Make sure that the base package is installed before installing
  the branding packages (needed for gconf schema update)
  (bnc#444682)
* Fri Nov  7 2008 maw@suse.de
- Review and approve changes.
* Tue Nov  4 2008 wr@rosenauer.org
- added the Firefox Gconf schema for system prefs and
  changed the homepage URL to http://www.opensuse.org/ (bnc#441646)
* Mon Oct 20 2008 maw@suse.de
- Review and approve changes.
* Tue Oct  7 2008 wr@rosenauer.org
- bumped version to 3.0.3
- removed browser.link.open_external override; we are opening
  everything in a new tab; that also caused UI misbehaviour
  (bnc#430077, bmo#457092)
- Set browser.identity.ssl_domain.display to 1 (bnc#426263)
* Tue Oct  7 2008 vuntz@novell.com
- Add openSUSE documentation bookmark (fate#305003).
- Also remove the Novell bookmarks and search addons. They will go
  in the SLED branding package.
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Fri Sep 26 2008 vuntz@suse.de
- Add COPYING file (bnc#426320).
* Sun Aug  3 2008 wr@rosenauer.org
- some polishing and minor changes
* Tue Jul 29 2008 vuntz@novell.com
- New package (bnc#390752).
